from dotenv_vault import load_dotenv
load_dotenv()

def run_tests():
    print("Running tests...")
    # TODO: run tests
    print("Tests complete.")
    sys.exit(0)


if __name__ == "__main__":
    run_tests()
